==> pointsto-19.3.0-sources.jar: com/oracle/graal/pointsto/flow/WordToObjectTypeFlow.java <==
/*
 * Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.graal.pointsto.flow;

import org.graalvm.compiler.graph.Node;

/**
 * Models an 'word to object' operation, i.e., reading an object from a pointer. The input is thus
 * the all instantiated type flow.
 */
public class WordToObjectTypeFlow extends ProxyTypeFlow {

    public WordToObjectTypeFlow(Node source, TypeFlow<?> input) {
        super(source, input);
    }

    @Override
    public String toString() {
        return "WordToObjectFlow<" + input + ">";
    }
}

==> pointsto-20.2.0-sources.jar: com/oracle/graal/pointsto/flow/WordToObjectTypeFlow.java <==
/*
 * Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.graal.pointsto.flow;

import org.graalvm.compiler.graph.Node;

import com.oracle.graal.pointsto.nodes.ConvertUnknownValueNode;

/**
 * Models an 'word to object' operation, i.e., reading an object from a pointer. The input is thus
 * the *unknown* type flow, i.e., a place-holder type flow that signifies *any type*. We don't use
 * *all-instantiated* type flow because we don't care about individual types. Operations that use
 * this *value* must first convert it to actual types. See {@link ConvertUnknownValueNode} for
 * details.
 */
public class WordToObjectTypeFlow extends ProxyTypeFlow {

    public WordToObjectTypeFlow(Node source, TypeFlow<?> input) {
        super(source, input);
    }

    @Override
    public boolean canSaturate() {
        return false;
    }

    @Override
    public String toString() {
        return "WordToObjectFlow<" + input + ">";
    }
}
